tolower

Function tolower 

#[unsafe(no_mangle)]
pub extern "C" fn tolower(c: c_int) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/tolower.html.

Returns the corresponding lowercase character for c according to the current locale, otherwise returns the input unchanged.

The list of character classes defined by POSIX is specified here: https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/V1_chap07.html