tolower_l

Function tolower_l 

#[unsafe(no_mangle)]
pub extern "C" fn tolower_l(c: c_int, _loc: locale_t) -> c_int
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/tolower_l.html.

Returns the corresponding lowercase character for c according to the locale specified by loc, otherwise returns the input unchanged.

The list of character classes defined by POSIX is specified here: https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/V1_chap07.html